package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.ConferenceRoomOrder;

/**
 * 会议室预约Service接口
 * 
 * @author ruoyi
 * @date 2024-07-23
 */
public interface IConferenceRoomOrderService 
{
    /**
     * 查询会议室预约
     * 
     * @param conferenceRoomOrderId 会议室预约主键
     * @return 会议室预约
     */
    public ConferenceRoomOrder selectConferenceRoomOrderByConferenceRoomOrderId(Long conferenceRoomOrderId);

    /**
     * 查询会议室预约列表
     * 
     * @param conferenceRoomOrder 会议室预约
     * @return 会议室预约集合
     */
    public List<ConferenceRoomOrder> selectConferenceRoomOrderList(ConferenceRoomOrder conferenceRoomOrder);

    /**
     * 新增会议室预约
     * 
     * @param conferenceRoomOrder 会议室预约
     * @return 结果
     */
    public AjaxResult insertConferenceRoomOrder(ConferenceRoomOrder conferenceRoomOrder);

    /**
     * 修改会议室预约
     * 
     * @param conferenceRoomOrder 会议室预约
     * @return 结果
     */
    public AjaxResult updateConferenceRoomOrder(ConferenceRoomOrder conferenceRoomOrder);

    /**
     * 批量删除会议室预约
     * 
     * @param conferenceRoomOrderIds 需要删除的会议室预约主键集合
     * @return 结果
     */
    public int deleteConferenceRoomOrderByConferenceRoomOrderIds(Long[] conferenceRoomOrderIds);

    /**
     * 删除会议室预约信息
     * 
     * @param conferenceRoomOrderId 会议室预约主键
     * @return 结果
     */
    public int deleteConferenceRoomOrderByConferenceRoomOrderId(Long conferenceRoomOrderId);
}
